@@ -135,15 +135,16 @@ def _patch() -> None:
 
         SuiteStructureParser._build_suite_directory = build_suite_directory
 
-        old_validate_execution_mode = SuiteStructureParser._validate_execution_mode
+        if get_robot_version() < (6, 1, 1):
+            old_validate_execution_mode = SuiteStructureParser._validate_execution_mode
 
-        def _validate_execution_mode(self: SuiteStructureParser, suite: TestSuite) -> None:
-            try:
-                old_validate_execution_mode(self, suite)
-            except DataError as e:
-                LOGGER.error(f"Parsing '{suite.source}' failed: {e.message}")
+            def _validate_execution_mode(self: SuiteStructureParser, suite: TestSuite) -> None:
+                try:
+                    old_validate_execution_mode(self, suite)
+                except DataError as e:
+                    LOGGER.error(f"Parsing '{suite.source}' failed: {e.message}")
 
-        SuiteStructureParser._validate_execution_mode = _validate_execution_mode
+            SuiteStructureParser._validate_execution_mode = _validate_execution_mode
 
     old_get_file = FileReader._get_file
 
@@ -429,7 +430,7 @@ def handle_options(
     raise UnknownError("Unexpected error happened.")
 
 
-@discover.command(  # type: ignore[attr-defined]
+@discover.command(
     context_settings={
         "allow_extra_args": True,
         "ignore_unknown_options": True,
@@ -464,17 +465,28 @@ def all(
 
     if collector.all.children:
         if app.config.output_format is None or app.config.output_format == OutputFormat.TEXT:
-            tests_or_tasks = "Tasks" if suite.rpa else "Tests"
+            tests_or_tasks = "Task" if suite.rpa else "Test"
 
             def print(item: TestItem, indent: int = 0) -> Iterable[str]:
-                yield (
-                    f"{'  ' * indent}"
-                    f"{item.type.capitalize() if item.type == 'suite' else tests_or_tasks.capitalize() }: "
-                    f"{item.name}{os.linesep}"
+                type = click.style(
+                    item.type.capitalize() if item.type == "suite" else tests_or_tasks.capitalize(), fg="green"
                 )
-                if item.children:
-                    for child in item.children:
-                        yield from print(child, indent + 2)
+
+                if item.type == "test":
+                    yield f"    {type}: {item.longname}{os.linesep}"
+                else:
+                    yield f"{type}: {item.longname}{os.linesep}"
+
+                for child in item.children or []:
+                    yield from print(child, indent + 2)
+
+                # type = click.style(
+                #     item.type.capitalize() if item.type == "suite" else tests_or_tasks.capitalize(), fg="green"
+                # )
+                # yield (f"{'  ' * indent}{type}: {item.name}{os.linesep}")
+                # if item.children:
+                #     for child in item.children:
+                #         yield from print(child, indent + 2)
 
                 if indent == 0:
                     yield os.linesep
@@ -489,7 +501,7 @@ def all(
             app.print_data(ResultItem([collector.all], diagnostics), remove_defaults=True)
 
 
-@discover.command(  # type: ignore[attr-defined]
+@discover.command(
     context_settings={
         "allow_extra_args": True,
         "ignore_unknown_options": True,
@@ -536,7 +548,7 @@ def tests(
             app.print_data(ResultItem(collector.tests, diagnostics), remove_defaults=True)
 
 
-@discover.command(  # type: ignore[attr-defined]
+@discover.command(
     context_settings={
         "allow_extra_args": True,
         "ignore_unknown_options": True,
@@ -588,7 +600,7 @@ class TagsResult:
     tags: Dict[str, List[TestItem]]
 
 
-@discover.command(  # type: ignore[attr-defined]
+@discover.command(
     context_settings={
         "allow_extra_args": True,
         "ignore_unknown_options": True,
@@ -637,31 +649,11 @@ def tags(
             app.print_data(TagsResult(collector.tags), remove_defaults=True)
 
 
-@dataclass
-class RobotVersion:
-    major: int
-    minor: int
-    patch: Optional[int] = None
-    pre_id: Optional[str] = None
-    pre_number: Optional[int] = None
-    dev: Optional[int] = None
-
-
-@dataclass
-class PythonVersion:
-    major: int
-    minor: int
-    micro: int
-    releaselevel: str
-    serial: int
-
-
 @dataclass
 class Info:
-    robot_version: RobotVersion
     robot_version_string: str
     robot_env: Dict[str, str]
-    python_version: PythonVersion
+    robotcode_version_string: str
     python_version_string: str
     machine: str
     processor: str
@@ -670,7 +662,7 @@ class Info:
     system_version: str
 
 
-@discover.command(  # type: ignore[attr-defined]
+@discover.command(
     add_help_option=True,
 )
 @pass_application
@@ -686,7 +678,12 @@ def info(
     robotcode discover info
     ```
     """
+    import pprint
+
     from robot.version import get_version as get_version
+    from robotcode.core.dataclasses import as_dict
+
+    from ...__version__ import __version__
 
     robot_env: Dict[str, str] = {}
     if "ROBOT_OPTIONS" in os.environ:
@@ -699,10 +696,9 @@ def info(
         robot_env["ROBOT_INTERNAL_TRACES"] = os.environ["ROBOT_INTERNAL_TRACES"]
 
     info = Info(
-        RobotVersion(*get_robot_version()),
         get_version(),
         robot_env,
-        PythonVersion(*sys.version_info),
+        __version__,
         platform.python_version(),
         platform.machine(),
         platform.processor(),
@@ -712,6 +708,7 @@ def info(
     )
 
     if app.config.output_format is None or app.config.output_format == OutputFormat.TEXT:
-        app.print_data(info, remove_defaults=True)
+        app.echo_via_pager(pprint.pformat(as_dict(info, remove_defaults=True), compact=True, sort_dicts=False))
+        # app.print_data(info, remove_defaults=True)
     else:
         app.print_data(info, remove_defaults=True)
